import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { AuthAttributes, AuthRootState, ModifyAuthAttributePayload } from './types';

const initialState: AuthAttributes = {
	authenticated: undefined,
	accessToken: undefined,
	refreshToken: undefined,
};

const authSlice = createSlice({
	name: 'auth',
	initialState,
	reducers: {
		setAuthAttributes: (state, action: PayloadAction<AuthAttributes<any>>) => {
			return {
				...state,
				...action.payload,
			};
		},
		updateAuthAttribute: {
			prepare: (key, value) => ({
				payload: { key, value },
			}),
			reducer: (state, action: PayloadAction<ModifyAuthAttributePayload>) => {
				state[action.payload.key] = action.payload.value;
			},
		},
		deleteAuthAttributes: () => {
			return initialState;
		},
	},
});

export const { deleteAuthAttributes } = authSlice.actions;

export const setAuthAttributes = authSlice.actions.setAuthAttributes as <T>(
	attrs: AuthAttributes<T>,
) => PayloadAction<AuthAttributes<T>>;

export const updateAuthAttribute = authSlice.actions.updateAuthAttribute as <T>(
	key: keyof AuthAttributes<T>,
	value: unknown,
) => PayloadAction<ModifyAuthAttributePayload<T>>;

export const getAuthAttributes = <T>(state: AuthRootState<T>) => state.procyon.auth as AuthAttributes<T>;

export default authSlice.reducer;
