import React from 'react';

import { FetchLoader } from '@procyon/api/components/FetchLoader';
import { Button } from '@procyon/components/Button';
import { Grid, GridSizeEnum } from '@procyon/components/Grid';
import { GridCol } from '@procyon/components/GridCol';
import { StatusEnum } from '@procyon/types/enums';

import { useLazyGetTodosQuery } from './api';
import Placeholder from './Placeholder';

const { md } = GridSizeEnum;

export const FetchComponent = (): React.ReactElement => {
	const [getTodos, { isFetching, data }] = useLazyGetTodosQuery();

	const handleFetch = async (id: number) => {
		await getTodos(id);
	};

	return (
		<>
			<Grid cols={{ [md]: 4 }}>
				<GridCol>
					<Button status={StatusEnum.warning} label="Odeslat" onClick={() => handleFetch(1)} disabled={isFetching} />
				</GridCol>
			</Grid>
			<FetchLoader active={isFetching} placeholder={<Placeholder />}>
				<pre>{JSON.stringify(data, undefined, 2)}</pre>
			</FetchLoader>
		</>
	);
};
